part of '../../public.dart';

abstract class IdentityModel<IdType> extends Model {
  static const String idTag = "id";
  final IdType id;

  const IdentityModel({required this.id});
  IdentityModel.fromMap(super.map)
      : id = map[idTag] as IdType,
        super.fromMap();

  @override
  Map<String, dynamic> toMap() => {idTag: id};

  @override
  List<Object?> get props => [id];
}

extension IdentityModelExtension<
    IdType,
    ModelType extends IdentityModel<IdType>>
    on Iterable<ModelType> {
  ModelType? firstWhereById(IdType? id) =>
      firstWhereOrNull((element) => element.id == id);
  ModelType? lastWhereById(IdType? id) =>
      lastWhereOrNull((element) => element.id == id);
}
